@@ -28,8 +28,7 @@ namespace Cairo
 {
 
 /**
- * This is a reference-counted object. The copy constructor creates a second reference to the object, instead 
- * of creating an independent copy of the object.
+ * This is a reference-counted object that should be used via Cairo::RefPtr.
  */
 class Pattern
 {
@@ -50,6 +49,7 @@ public:
 
   void set_matrix(const cairo_matrix_t &matrix);
   void get_matrix(cairo_matrix_t &matrix) const;
+  PatternType get_type() const;
 
   typedef cairo_pattern_t cobject;
   inline cobject* cobj() { return m_cobject; }
