@@ -20,6 +20,7 @@
 #define __CAIROMM_SURFACE_H
 
 #include <string>
+#include <vector>
 #include <cairomm/enums.h>
 #include <cairomm/exception.h>
 #include <cairomm/fontoptions.h>
@@ -28,7 +29,6 @@
 //See xlib_surface.h for XlibSurface.
 //See win32_surface.h for Win32Surface.
 
-// Experimental surfaces
 #ifdef CAIRO_HAS_PDF_SURFACE
 #include <cairo-pdf.h>
 #endif // CAIRO_HAS_PDF_SURFACE
@@ -38,6 +38,8 @@
 #ifdef CAIRO_HAS_SVG_SURFACE
 #include <cairo-svg.h>
 #endif // CAIRO_HAS_SVG_SURFACE
+
+// Experimental surfaces
 #ifdef CAIRO_HAS_GLITZ_SURFACE
 #include <cairo-glitz.h>
 #endif // CAIRO_HAS_GLITZ_SURFACE
@@ -51,9 +53,7 @@ namespace Cairo
  * different subtypes of cairo surface for different drawing backends.  This
  * class is a base class for all subtypes and should not be used directly
  *
- * Surfaces are reference-counted objects. The copy constructor creates a
- * second reference to the object, instead of creating an independent copy of
- * the object.
+ * Surfaces are reference-counted objects that should be used via Cairo::RefPtr. 
  */
 class Surface
 {
@@ -137,11 +137,24 @@ public:
    */
   void set_device_offset(double x_offset, double y_offset);
 
+  /** Returns a previous device offset set by set_device_offset().
+   */
+  void get_device_offset(double& x_offset, double& y_offset) const;
+
+  /** Sets the fallback resolution of the image in dots per inch
+   *
+   * @param x_pixels_per_inch   Pixels per inch in the x direction
+   * @param y_pixels_per_inch   Pixels per inch in the y direction
+   */
+  void set_fallback_resolution(double x_pixels_per_inch, double y_pixels_per_inch);
+
+  SurfaceType get_type() const;
+
 #ifdef CAIRO_HAS_PNG_FUNCTIONS
 
   /** Writes the contents of surface to a new file filename as a PNG image.
    *
-   * \note For this function to be available, cairo must have been compiled
+   * @note For this function to be available, cairo must have been compiled
    * with PNG support
    *
    * @param filename	the name of a file to write to
@@ -150,7 +163,7 @@ public:
 
   /** Writes the Surface to the write function.
    *
-   * \note For this function to be available, cairo must have been compiled
+   * @note For this function to be available, cairo must have been compiled
    * with PNG support
    *
    * @param write_func  The function to be called when the backend needs to
@@ -214,9 +227,7 @@ protected:
  * if you modify anything and later want to continue to draw to the surface
  * with cairo, you must let cairo know via Cairo::Surface::mark_dirty() 
  *
- * Note that like all surfaces, an ImageSurface is a reference-counted object
- * in which the copy constructor creates a second reference to the Surface
- * instead of creating an independant copy
+ * Note that like all surfaces, an ImageSurface is a reference-counted object that should be used via Cairo::RefPtr.
  */
 class ImageSurface : public Surface
 {
@@ -243,6 +254,29 @@ public:
    */
   int get_height() const;
 
+  /**
+   * Get a pointer to the data of the image surface, for direct
+   * inspection or modification.
+   *
+   * Return value: a pointer to the image data of this surface or NULL
+   * if @surface is not an image surface.
+   */
+  unsigned char* get_data();
+  const unsigned char* get_data() const;
+
+  /** gets the format of the surface
+   */
+  Format get_format() const;
+
+  /**
+   * Return value: the stride of the image surface in bytes (or 0 if
+   * @surface is not an image surface). The stride is the distance in
+   * bytes from the beginning of one row of the image data to the
+   * beginning of the next row.
+   */
+  int get_stride() const;
+
+
   /** Creates an image surface of the specified format and dimensions. The
    * initial contents of the surface is undefined; you must explicitely clear
    * the buffer, using, for example, Cairo::Context::rectangle() and
@@ -290,7 +324,7 @@ public:
   /** Creates a new image surface and initializes the contents to the given PNG
    * file.  
    *
-   * \note For this function to be available, cairo must have been compiled
+   * @note For this function to be available, cairo must have been compiled
    * with PNG support.
    *
    * @param filename	name of PNG file to load
@@ -302,7 +336,7 @@ public:
   /** Creates a new image surface from PNG data read incrementally via the
    * read_func function.  
    *
-   * \note For this function to be available, cairo must have been compiled
+   * @note For this function to be available, cairo must have been compiled
    * with PNG support.
    *
    * @param read_func	function called to read the data of the file
@@ -317,21 +351,14 @@ public:
 };
 
 
-/*******************************************************************************
- * THE FOLLOWING SURFACE TYPES ARE EXPERIMENTAL AND NOT FULLY SUPPORTED
- ******************************************************************************/
-
 #ifdef CAIRO_HAS_PDF_SURFACE
 
 /** A PdfSurface provides a way to render PDF documents from cairo.  This
  * surface is not rendered to the screen but instead renders the drawing to a
  * PDF file on disk.
  *
- * \note For this Surface to be available, cairo must have been compiled with
+ * @note For this Surface to be available, cairo must have been compiled with
  * PDF support
- *
- * \warning This is an experimental surface.  It is not yet marked as a fully
- * supported surface by the cairo library
  */
 class PdfSurface : public Surface
 {
@@ -367,12 +394,19 @@ public:
    */
   static RefPtr<PdfSurface> create(cairo_write_func_t write_func, void *closure, double width_in_points, double height_in_points);
 
-  /** Sets the resolution of the image in dots per inch
-   *
-   * @param x_dpi   The dpi in the x direction
-   * @param y_dpi    The dpi in the y direction
-   */
-  void set_dpi(double x_dpi, double y_dpi);
+/**
+ * Changes the size of a PDF surface for the current (and subsequent) pages.
+ *
+ * This function should only be called before any drawing operations have been
+ * performed on the current page. The simplest way to do this is to call this
+ * function immediately after creating the surface or immediately after
+ * completing a page with either Context::show_page() or Context::copy_page().
+ *
+ * @param width_in_points new surface width, in points (1 point == 1/72.0 inch)
+ * @param height_in_points new surface height, in points (1 point == 1/72.0 inch)
+ **/
+  void set_size(double width_in_points, double height_in_points);
+
 };
 
 #endif  // CAIRO_HAS_PDF_SURFACE
@@ -384,11 +418,8 @@ public:
  * surface is not rendered to the screen but instead renders the drawing to a
  * PostScript file on disk.
  *
- * \note For this Surface to be available, cairo must have been compiled with
+ * @note For this Surface to be available, cairo must have been compiled with
  * PostScript support
- *
- * \warning This is an experimental surface.  It is not yet marked as a fully
- * supported surface by the cairo library
  */
 class PsSurface : public Surface
 {
@@ -424,12 +455,45 @@ public:
    */
   static RefPtr<PsSurface> create(cairo_write_func_t write_func, void *closure, double width_in_points, double height_in_points);
 
-  /** Sets the resolution of the image in dots per inch
+  /**
+   * Changes the size of a PostScript surface for the current (and
+   * subsequent) pages.
    *
-   * @param x_dpi   The dpi in the x direction
-   * @param y_dpi    The dpi in the y direction
+   * This function should only be called before any drawing operations have been
+   * performed on the current page. The simplest way to do this is to call this
+   * function immediately after creating the surface or immediately after
+   * completing a page with either Context::show_page() or Context::copy_page().
+   *
+   * @param width_in_points new surface width, in points (1 point == 1/72.0 inch)
+   * @param height_in_points new surface height, in points (1 point == 1/72.0 inch)
    */
-  void set_dpi(double x_dpi, double y_dpi);
+  void set_size(double width_in_points, double height_in_points);
+
+  /** Emit a comment into the PostScript output for the given surface.  See the
+   * cairo reference documentation for more information.
+   *
+   * @param comment a comment string to be emitted into the PostScript output
+   */
+  void dsc_comment(std::string comment);
+
+  /**
+   * This function indicates that subsequent calls to dsc_comment() should direct
+   * comments to the Setup section of the PostScript output.
+   *
+   * This function should be called at most once per surface, and must be called
+   * before any call to dsc_begin_page_setup() and before any drawing is performed
+   * to the surface.
+   */
+  void dsc_begin_setup();
+
+  /** This function indicates that subsequent calls to dsc_comment() should
+   * direct comments to the PageSetup section of the PostScript output.
+   *
+   * This function call is only needed for the first page of a surface. It
+   * should be called after any call to dsc_begin_setup() and before any drawing
+   * is performed to the surface.
+   */
+  void dsc_begin_page_setup();
 
 };
 
@@ -438,15 +502,18 @@ public:
 
 #ifdef CAIRO_HAS_SVG_SURFACE
 
+typedef enum
+{
+  SVG_VERSION_1_1 = CAIRO_SVG_VERSION_1_1,
+  SVG_VERSION_1_2 = CAIRO_SVG_VERSION_1_2
+} SvgVersion;
+
 /** A SvgSurface provides a way to render Scalable Vector Graphics (SVG) images
  * from cairo.  This surface is not rendered to the screen but instead renders
  * the drawing to an SVG file on disk.
  *
- * \note For this Surface to be available, cairo must have been compiled with
+ * @note For this Surface to be available, cairo must have been compiled with
  * SVG support
- *
- * \warning This is an experimental surface.  It is not yet marked as a fully
- * supported surface by the cairo library
  */
 class SvgSurface : public Surface
 {
@@ -483,17 +550,41 @@ public:
    */
   static RefPtr<SvgSurface> create(cairo_write_func_t write_func, void *closure, double width_in_points, double height_in_points);
 
-  /** Sets the resolution of the image in dots per inch
+  /** 
+   * Restricts the generated SVG file to the given version. See get_versions()
+   * for a list of available version values that can be used here.
    *
-   * @param x_dpi   The dpi in the x direction
-   * @param y_dpi    The dpi in the y direction
+   * This function should only be called before any drawing operations have been
+   * performed on the given surface. The simplest way to do this is to call this
+   * function immediately after creating the surface.
+   *
+   * @since 1.2
    */
-  void set_dpi(double x_dpi, double y_dpi);
+  void restrict_to_version(SvgVersion version);
+
+  /** Retrieves the list of SVG versions supported by cairo. See
+   * restrict_to_version().
+   * 
+   * @since 1.2
+   */
+  static const std::vector<SvgVersion> get_versions();
+
+  /** Get the string representation of the given version id. The returned string
+   * will be empty if version isn't valid. See get_versions() for a way to get
+   * the list of valid version ids.
+   *
+   * Since: 1.2
+   */
+  static std::string version_to_string(SvgVersion version);
 };
 
 #endif // CAIRO_HAS_SVG_SURFACE
 
 
+/*******************************************************************************
+ * THE FOLLOWING SURFACE TYPES ARE EXPERIMENTAL AND NOT FULLY SUPPORTED
+ ******************************************************************************/
+
 #ifdef CAIRO_HAS_GLITZ_SURFACE
 
 /** A GlitzSurface provides a way to render to the X Window System using Glitz.
@@ -501,10 +592,10 @@ public:
  * want to use hardware-accelerated graphics within the X Window system, you
  * should use this Surface type.
  *
- * \note For this Surface to be available, cairo must have been compiled with
+ * @note For this Surface to be available, cairo must have been compiled with
  * Glitz support
  *
- * \warning This is an experimental surface.  It is not yet marked as a fully
+ * @warning This is an experimental surface.  It is not yet marked as a fully
  * supported surface by the cairo library
  */
 class GlitzSurface : public Surface
