@@ -3,6 +3,12 @@
 #include <cairomm/context.h>
 #include <cairomm/surface.h>
 
+/* M_PI is defined in math.h in the case of Microsoft Visual C++ */
+#if defined(_MSC_VER)
+#define _USE_MATH_DEFINES
+#include <math.h>
+#endif 
+
 int main(int argc, char** argv)
 {
 #ifdef CAIRO_HAS_PS_SURFACE
